package com.muyu.goods.controller;

import com.business.common.domain.Fence;
import com.business.common.domain.FenceGroups;
import com.business.common.domain.Path;
import com.business.common.psvm.Pences;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.goods.service.IMapService;
import com.muyu.goods.service.impl.MapService;
import org.apache.commons.codec.language.bm.Rule;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("map")
public class MapController extends BaseController {
    @Autowired
    private IMapService iMapService;

    /**
     * 查看全部围栏组
     * @return
     */
    @PostMapping("selectFenceGroups")
    public Result<List<FenceGroups>> selectFenceGroups() {
        return success(iMapService.selectFenceGroups());
    }

    /**
     * 查看全部电子围栏
     * @return
     */
    @PostMapping("selectFence")
    public Result<List<Fence>> selectFence() {
        return success(iMapService.selectFence());
    }

    /**
     * 查看围栏组
     * @param carId
     * @return
     */
    @PostMapping("selectFenceGroupsById/{carId}")
    public Result<FenceGroups> selectFenceGroupsById(@PathVariable Long carId){
        return success(iMapService.selectFenceGroupsById(carId));
    }

    /**
     * 获取电子围栏
     * @param list
     * @return
     */
    @PostMapping("getSel")
    public Result getSel(@RequestBody Pences list){
        return success(iMapService.getSel(list));
    }

    /**
     * 电子围栏
     * @param fenceId
     * @return
     */
    @PostMapping("deleteFence/{fenceId}")
    public Result deleteFence(@PathVariable Long fenceId){
        return success(iMapService.deleteFence(fenceId));
    }

    /**
     * 查看详情
     * @param fenceId
     * @return
     */
    @PostMapping("queryFence/{fenceId}")
    public Result<Fence> queryFence(@PathVariable Long fenceId){
        return success(iMapService.queryFence(fenceId));
    }

    /**
     * 修改状态
     * @param fenceId
     * @return
     */
    @PostMapping("updateFence/{fenceId}")
    public Result updateFence(@PathVariable Long fenceId) {
        return success(iMapService.updateFence(fenceId));
    }
}
