package com.muyu.goods.service.impl;

import java.util.List;
import java.util.UUID;
import java.util.stream.Collectors;

import com.business.common.domain.Car;
import com.business.common.domain.Enterprise;
import com.muyu.goods.mapper.CarMapper;
import com.muyu.goods.mapper.MapMapper;
import com.muyu.goods.service.ICarService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 车辆信息Service业务层处理
 *
 * @author muyu
 * @date 2024-05-27
 */
@Service
public class CarServiceImpl implements ICarService
{
    @Autowired
    private CarMapper carMapper;
    @Autowired
    private BusinessServiceImpl businessService;
    @Autowired
    private MapMapper mapMapper;

    /**
     * 查询车辆信息
     *
     * @param carId 车辆信息主键
     * @return 车辆信息
     */
    @Override
    public Car selectCarByCarId(Long carId)
    {
        return carMapper.selectCarByCarId(carId);
    }

    /**
     * 查询车辆信息列表
     *
     * @param car 车辆信息
     * @return 车辆信息
     */
    @Override
    public List<Car> selectCarList(Car car)
    {
        Enterprise enterprise = businessService.listEnterprise();
        List<Car> list = carMapper.selectCarList(car);
        if (enterprise == null){
            return list;
        }else {
            List<Car> carList = list.stream().filter(cars -> cars.getOwnerId().equals(enterprise.getId())).collect(Collectors.toList());
            return carList;
        }

    }

    /**
     * 新增车辆信息
     *
     * @param car 车辆信息
     * @return 结果
     */
    @Override
    public int insertCar(Car car)
    {
        Enterprise enterprise = businessService.listEnterprise();
        if (enterprise == null){
            return 0;
        }
        System.out.println(enterprise);
        car.setOwnerId(enterprise.getId());
        car.setVin(UUID.randomUUID().toString().replaceAll("-",""));
        int i = carMapper.insertCar(car);
        if (i>0) {
            Car car1 = carMapper.carByCar();
            System.out.println(car1);
            mapMapper.indexFenceGroups(car1.getCarId(),"car"+car1.getCarId());
        }
        return i;
    }

    /**
     * 修改车辆信息
     *
     * @param car 车辆信息
     * @return 结果
     */
    @Override
    public int updateCar(Car car)
    {
        return carMapper.updateCar(car);
    }

    /**
     * 批量删除车辆信息
     *
     * @param carIds 需要删除的车辆信息主键
     * @return 结果
     */
    @Override
    public int deleteCarByCarIds(Long[] carIds)
    {
        return carMapper.deleteCarByCarIds(carIds);
    }

    /**
     * 删除车辆信息信息
     *
     * @param carId 车辆信息主键
     * @return 结果
     */
    @Override
    public int deleteCarByCarId(Long carId)
    {
        return carMapper.deleteCarByCarId(carId);
    }

    @Override
    public Car query(Long carId) {
        return carMapper.query(carId);
    }
}
